@@ -29,6 +29,11 @@ from .validate import avro_type_name
 _logger = logging.getLogger("salad")
 
 
+def vocab_type_name(url: str) -> str:
+    """Remove the avro namespace, if any."""
+    return avro_type_name(url).split(".")[-1]
+
+
 def has_types(items: Any) -> List[str]:
     r = []  # type: List[str]
     if isinstance(items, MutableMapping):
@@ -317,7 +322,7 @@ class RenderType:
                 "https://w3id.org/cwl/salad#record",
                 "https://w3id.org/cwl/salad#enum",
             ):
-                frg = avro_type_name(tp["name"])
+                frg = vocab_type_name(tp["name"])
                 if tp["name"] in redirects:
                     return """<a href="{}">{}</a>""".format(redirects[tp["name"]], frg)
                 if tp["name"] in self.typemap:
@@ -337,7 +342,7 @@ class RenderType:
                 return f"""<a href="{redirects[tp]}">{redirects[tp]}</a>"""
             if str(tp) in basicTypes:
                 return """<a href="{}">{}</a>""".format(
-                    self.primitiveType, avro_type_name(str(tp))
+                    self.primitiveType, vocab_type_name(str(tp))
                 )
             frg2 = urldefrag(tp)[1]
             if frg2 != "":
@@ -514,10 +519,10 @@ def avrold_doc(
 
     if brandstyle is None:
         bootstrap_url = (
-            "https://maxcdn.bootstrapcdn.com/bootstrap/3.3.4/css/bootstrap.min.css"
+            "https://cdn.jsdelivr.net/npm/bootstrap@5.0.2/dist/css/bootstrap.min.css"
         )
         bootstrap_integrity = (
-            "sha384-604wwakM23pEysLJAhja8Lm42IIwYrJ0dEAqzFsj9pJ/P5buiujjywArgPCi8eoz"
+            "sha384-EVSTQN3/azprG1Anm3QDgpJLIm9Nao0Yz1ztcQTwFspd3yD65VohhpuuCOmLASjC"
         )
         brandstyle_template = (
             '<link rel="stylesheet" href={} integrity={} crossorigin="anonymous">'
@@ -559,15 +564,43 @@ def avrold_doc(
       padding-top: 61px;
       margin-top: -61px;
     }
-    body {
-      padding-top: 61px;
-    }
     .tocnav ol {
       list-style: none
     }
     pre {
-      margin-left: 2em;
-      margin-right: 2em;
+      margin: 0 2em 10px 2em;
+      padding: 9.5px;
+      line-height: 1.42857143;
+      color: #333;
+      word-break: break-all;
+      word-wrap: break-word;
+      background-color: #f5f5f5;
+      border: 1px solid #ccc;
+      border-radius: 4px;
+    }
+    pre code {
+      padding: 0;
+      font-size: inherit;
+      color: inherit;
+      white-space: pre-wrap;
+      background-color: transparent;
+      border-radius: 0;
+    }
+    code {
+      background-color: #f9f2f4;
+      border-radius: 4px;
+      padding: 2px 4px;
+      color: #c7254e;
+    }
+    blockquote {
+      padding: 10px 20px 1px 20px;
+      border-left: 5px solid #eee;
+    }
+    a {
+      text-decoration: none;
+    }
+    a code {
+      color: #c7254e;
     }
     .section a {
       visibility: hidden;
@@ -624,10 +657,9 @@ def avrold_doc(
     navbar_extraclass = "navbar-inverse" if brandinverse else ""
     outdoc.write(
         """
-      <nav class="navbar navbar-default navbar-fixed-top {}">
+      <nav class="navbar sticky-top navbar-expand-lg navbar-light bg-light {}">
         <div class="container">
-          <div class="navbar-header">
-            <a class="navbar-brand" href="{}">{}</a>
+          <a class="navbar-brand" href="{}">{}</a>
     """.format(
             navbar_extraclass, brandlink, brand
         )
@@ -637,15 +669,14 @@ def avrold_doc(
         content = content.replace("<!--ToC-->", toc.contents("toc"))
         outdoc.write(
             """
-                <ul class="nav navbar-nav">
-                  <li><a href="#toc">Table of contents</a></li>
-                </ul>
+              <ul class="navbar-nav me-auto">
+                <li class="nav-item"><a class="nav-link" href="#toc">Table of contents</a></li>
+              </ul>
         """
         )
 
     outdoc.write(
         """
-          </div>
         </div>
       </nav>
     """
@@ -653,7 +684,7 @@ def avrold_doc(
 
     outdoc.write(
         """
-    <div class="container">
+    <div class="container mt-4">
     """
     )
 
@@ -692,12 +723,15 @@ def arg_parser() -> argparse.ArgumentParser:
     parser.add_argument("--brandstyle")
     parser.add_argument("--brandinverse", default=False, action="store_true")
     parser.add_argument("--primtype", default="#PrimitiveType")
+    parser.add_argument("--debug", action="store_true")
     return parser
 
 
 def main() -> None:
     """Shortcut entrypoint."""
     args = arg_parser().parse_args()
+    if args.debug:
+        _logger.setLevel(logging.DEBUG)
     makedoc(
         sys.stdout,
         args.schema,
