@@ -97,10 +97,12 @@ class PythonCodeGen(CodeGenBase):
         avn = schema.avro_field_name(name)
         if avn.startswith("anon."):
             avn = avn[5:]
-        if avn in ("class", "in"):
+        elif avn[0].isdigit():
+            avn = f"_{avn}"
+        elif avn in ("class", "in"):
             # reserved words
-            avn = avn + "_"
-        return avn
+            avn = f"{avn}_"
+        return avn.replace(".", "_")
 
     def prologue(self) -> None:
         """Trigger to generate the prolouge code."""
@@ -416,7 +418,7 @@ if _errors__:
                         self.safe_name(type_declaration["name"]) + "Loader",
                         '_EnumLoader(("{}",), "{}")'.format(
                             '", "'.join(
-                                self.safe_name(sym)
+                                schema.avro_field_name(sym)
                                 for sym in type_declaration["symbols"]
                             ),
                             self.safe_name(type_declaration["name"]),
@@ -457,12 +459,11 @@ if _errors__:
         fieldtype: TypeDef,
         doc: str,
         optional: bool,
-        subscope: Optional[str],
     ) -> None:
         if self.current_class_is_abstract:
             return
 
-        self.declare_field(name, fieldtype, doc, True)
+        self.declare_field(name, fieldtype, doc, True, "")
 
         if optional:
             opt = """{safename} = "_:" + str(_uuid__.uuid4())""".format(
@@ -473,9 +474,6 @@ if _errors__:
                 fieldname=shortname(name)
             )
 
-        if subscope is not None:
-            name = name + subscope
-
         self.out.write(
             """
         __original_{safename}_is_none = {safename} is None
@@ -492,7 +490,12 @@ if _errors__:
         )
 
     def declare_field(
-        self, name: str, fieldtype: TypeDef, doc: Optional[str], optional: bool
+        self,
+        name: str,
+        fieldtype: TypeDef,
+        doc: Optional[str],
+        optional: bool,
+        subscope: str,
     ) -> None:
 
         if self.current_class_is_abstract:
@@ -506,12 +509,25 @@ if _errors__:
             spc = "    "
         else:
             spc = ""
+
+        if subscope:
+            self.out.write(
+                """
+{spc}        subscope_baseuri = expand_url('{subscope}', baseuri, loadingOptions, True)
+""".format(
+                    subscope=subscope, spc=spc
+                )
+            )
+            baseurivar = "subscope_baseuri"
+        else:
+            baseurivar = "baseuri"
+
         self.out.write(
             """{spc}        try:
 {spc}            {safename} = load_field(
 {spc}                _doc.get("{fieldname}"),
 {spc}                {fieldtype},
-{spc}                baseuri,
+{spc}                {baseurivar},
 {spc}                loadingOptions,
 {spc}            )
 {spc}        except ValidationException as e:
@@ -526,6 +542,7 @@ if _errors__:
                 safename=self.safe_name(name),
                 fieldname=shortname(name),
                 fieldtype=fieldtype.name,
+                baseurivar=baseurivar,
                 spc=spc,
             )
         )
